@@ -1,3 +1,4 @@
+#TODO: Review docs.
 import numpy as np
 
 
@@ -72,11 +73,12 @@ class Scatterer(object):
         k = self.incident_wave_vector
         kp = self.scattered_wave_vector
         theta = np.arccos(k.dot(kp) / (np.linalg.norm(k)**2)) / 2.
-        korthogonal = kp - k * kp.dot(k) / np.linalg.norm(k**2)
+        korthogonal = kp - (k * kp.dot(k) / (np.linalg.norm(k)**2))
         eta = np.arccos(
             self.rotation_axis.dot(korthogonal) /
             np.linalg.norm(korthogonal))
-        if eta < 1e-8 or theta < 1e-8:
+        tol = 0.5
+        if np.abs(np.degrees(eta)) < tol or np.abs(np.degrees(eta)) > 180-tol or np.degrees(theta) < tol:
             return np.inf
         else:
             return 1. / (np.sin(2 * theta) * np.abs(np.sin(eta)))
