@@ -11,7 +11,8 @@ from xrd_simulator.xfab import tools
 from xrd_simulator.xfab import sg
 from xrd_simulator.xfab import atomlib
 
-def StructureFactor(hkl, ucell, sgname, atoms, disper = None):
+
+def StructureFactor(hkl, ucell, sgname, atoms, disper=None):
     """
     Calculation of the structure factor of reflection hkl
 
@@ -26,7 +27,7 @@ def StructureFactor(hkl, ucell, sgname, atoms, disper = None):
     Henning Osholm Sorensen, June 23, 2006.
     Translated to python code April 8, 2008
     """
-    mysg = sg.sg(sgname = sgname)
+    mysg = sg.sg(sgname=sgname)
     stl = tools.sintl(ucell, hkl)
     noatoms = len(atoms)
 
@@ -34,10 +35,10 @@ def StructureFactor(hkl, ucell, sgname, atoms, disper = None):
     Fimg = 0.0
 
     for i in range(noatoms):
-        #Check whether isotrop or anisotropic displacements
+        # Check whether isotrop or anisotropic displacements
         if atoms[i].adp_type == 'Uiso':
             U = atoms[i].adp
-            expij = n.exp(-8*n.pi**2*U*stl**2)
+            expij = n.exp(-8 * n.pi**2 * U * stl**2)
         elif atoms[i].adp_type == 'Uani':
             # transform Uij to betaij
             betaij = Uij2betaij(atoms[i].adp, ucell)
@@ -48,7 +49,7 @@ def StructureFactor(hkl, ucell, sgname, atoms, disper = None):
 
         # Atomic form factors
         f = FormFactor(atoms[i].atomtype, stl)
-        if disper == None or disper[atoms[i].atomtype] == None :
+        if disper is None or disper[atoms[i].atomtype] is None:
             fp = 0.0
             fpp = 0.0
         else:
@@ -63,17 +64,18 @@ def StructureFactor(hkl, ucell, sgname, atoms, disper = None):
 
             # exponent for phase factor
             r = n.dot(mysg.rot[j], atoms[i].pos) + mysg.trans[j]
-            exponent = 2*n.pi*n.dot(hkl, r)
+            exponent = 2 * n.pi * n.dot(hkl, r)
 
-            #forming the real and imaginary parts of F
+            # forming the real and imaginary parts of F
             s = n.sin(exponent)
             c = n.cos(exponent)
-            site_pop = atoms[i].occ*atoms[i].symmulti/mysg.nsymop
-            Freal = Freal + expij*(c*(f+fp)-s*fpp)*site_pop
-            Fimg = Fimg + expij*(s*(f+fp)+c*fpp)*site_pop
+            site_pop = atoms[i].occ * atoms[i].symmulti / mysg.nsymop
+            Freal = Freal + expij * (c * (f + fp) - s * fpp) * site_pop
+            Fimg = Fimg + expij * (s * (f + fp) + c * fpp) * site_pop
 
     return [Freal, Fimg]
 
+
 def Uij2betaij(adp, ucell):
     """
     Uij2betaij transform the ADP U-matrix into the beta form
@@ -89,21 +91,20 @@ def Uij2betaij(adp, ucell):
     Henning Osholm Sorensen, Risoe National Laboratory, June 23, 2006.
     Translated to python code March 29, 2008
     """
-    U  = n.array([[adp[0], adp[5], adp[4]],
-                  [adp[5], adp[1], adp[3]],
-                  [adp[4], adp[3], adp[2]]])
+    U = n.array([[adp[0], adp[5], adp[4]],
+                 [adp[5], adp[1], adp[3]],
+                 [adp[4], adp[3], adp[2]]])
 
     betaij = n.zeros((3, 3))
     cellstar = tools.cell_invert(ucell)
 
     for i in range(3):
         for j in range(3):
-            betaij[i, j] = 2*n.pi**2*cellstar[i]*cellstar[j]*U[i, j]
+            betaij[i, j] = 2 * n.pi**2 * cellstar[i] * cellstar[j] * U[i, j]
 
     return betaij
 
 
-
 def FormFactor(atomtype, stl):
     """
      Calculation of the atomic form factor at a specified sin(theta)/lambda
@@ -125,7 +126,7 @@ def FormFactor(atomtype, stl):
     formfac = 0
 
     for i in range(4):
-        formfac = formfac + data[i]*n.exp(-data[i+4]*stl*stl)
+        formfac = formfac + data[i] * n.exp(-data[i + 4] * stl * stl)
     formfac = formfac + data[8]
 
     return formfac
@@ -153,10 +154,10 @@ def int_intensity(F2, L, P, I0, wavelength, cell_vol, cryst_vol):
     echarge = 1.60217653e-19
     pi4eps0 = 1.11265e-10
     c = 299792458.0
-    k1 = (echarge**2/(pi4eps0*emass*c**2)*1000)**2 # Unit is mm
+    k1 = (echarge**2 / (pi4eps0 * emass * c**2) * 1000)**2  # Unit is mm
     # the factor 1e21 used below is to go from mm^3 to AA^3
-    k2 = wavelength**3 * cryst_vol * 1e21/cell_vol**2
-    return k1*k2*I0*L*P*F2
+    k2 = wavelength**3 * cryst_vol * 1e21 / cell_vol**2
+    return k1 * k2 * I0 * L * P * F2
 
 
 def multiplicity(position, sgname=None, sgno=None, cell_choice='standard'):
@@ -166,9 +167,9 @@ def multiplicity(position, sgname=None, sgno=None, cell_choice='standard'):
 
     """
 
-    if sgname != None:
+    if sgname is not None:
         mysg = sg.sg(sgname=sgname, cell_choice=cell_choice)
-    elif sgno !=None:
+    elif sgno is not None:
         mysg = sg.sg(sgno=sgno, cell_choice=cell_choice)
     else:
         raise ValueError('No space group information provided')
@@ -183,15 +184,16 @@ def multiplicity(position, sgname=None, sgno=None, cell_choice='standard'):
 
     for i in range(1, mysg.nsymop):
         for j in range(multi):
-            t = lp[i]-lpu[j]
+            t = lp[i] - lpu[j]
             if n.sum(n.mod(t, 1)) < 0.00001:
                 break
             else:
-                if j == multi-1:
+                if j == multi - 1:
                     lpu = n.concatenate((lpu, [lp[i, :]]))
                     multi += 1
     return multi
 
+
 class atom_entry:
     def __init__(self, label=None, atomtype=None, pos=None,
                  adp_type=None, adp=None, occ=None, symmulti=None):
@@ -203,6 +205,7 @@ class atom_entry:
         self.occ = occ
         self.symmulti = symmulti
 
+
 class atomlist:
     def __init__(self, sgname=None, sgno=None, cell=None):
         self.sgname = sgname
@@ -216,45 +219,49 @@ class atomlist:
                                     pos=pos, adp_type=adp_type,
                                     adp=adp, occ=occ, symmulti=symmulti))
 
+
 class build_atomlist:
     def __init__(self):
         self.atomlist = atomlist()
 
     def CIFopen(self, ciffile=None, cifblkname=None):
-        from CifFile import ReadCif # part of the PycifRW module
+        from CifFile import ReadCif  # part of the PycifRW module
         try:
             # the following is a trick to avoid that urllib.URLopen.open
             # used by ReadCif misinterprets the url when a drive:\ is
             # present (Win)
-            ciffile = ciffile.replace(':','|')
+            ciffile = ciffile.replace(':', '|')
             cf = ReadCif(ciffile)
-        except:
-            logging.error('File %s could not be accessed' %ciffile)
+        except BaseException:
+            logging.error('File %s could not be accessed' % ciffile)
 
-        if cifblkname == None:
-            #Try to guess blockname
+        if cifblkname is None:
+            # Try to guess blockname
             blocks = list(cf.keys())
             if len(blocks) > 1:
                 if len(blocks) == 2 and 'global' in blocks:
                     cifblkname = blocks[abs(blocks.index('global') - 1)]
                 else:
                     logging.error('More than one possible data set:')
-                    logging.error('The following data block names are in the file:')
+                    logging.error(
+                        'The following data block names are in the file:')
                     for block in blocks:
                         logging.error(block)
                     raise Exception
             else:
                 # Only one available
                 cifblkname = blocks[0]
-        #Extract block
+        # Extract block
         try:
             self.cifblk = cf[cifblkname]
-        except:
-            logging.error('Block - %s - not found in %s' % (blockname, ciffile))
+        except BaseException:
+            logging.error(
+                'Block - %s - not found in %s' %
+                (cifblkname, ciffile))
             raise IOError
         return self.cifblk
 
-    def PDBread(self, pdbfile = None):
+    def PDBread(self, pdbfile=None):
         """
         function to read pdb file (www.pdb.org) and make
         atomlist structure
@@ -262,10 +269,9 @@ class build_atomlist:
         from re import sub
         try:
             text = open(pdbfile, 'r').readlines()
-        except:
+        except BaseException:
             logging.error('File %s could not be accessed' % pdbfile)
 
-
         for i in range(len(text)):
             if text[i].find('CRYST1') == 0:
                 a = float(text[i][6:15])
@@ -293,44 +299,48 @@ class build_atomlist:
             if text[i].find('SCALE') == 0:
                 # FOUND SCALE LINE
                 scale = text[i].split()
-                scaleline = int(scale[0][-1])-1
+                scaleline = int(scale[0][-1]) - 1
                 for j in range(1, len(scale)):
-                    scalemat[scaleline, j-1] = float(scale[j])
+                    scalemat[scaleline, j - 1] = float(scale[j])
 
         no = 0
         for i in range(len(text)):
-            if text[i].find('ATOM') == 0 or text[i].find('HETATM') ==0:
+            if text[i].find('ATOM') == 0 or text[i].find('HETATM') == 0:
                 no = no + 1
-                label = sub("\s+", "", text[i][12:16])
-                atomtype = sub("\s+", "", text[i][76:78]).upper()
+                label = sub("\\s+", "", text[i][12:16])
+                atomtype = sub("\\s+", "", text[i][76:78]).upper()
                 x = float(text[i][30:38])
                 y = float(text[i][38:46])
                 z = float(text[i][46:54])
                 # transform orthonormal coordinates to fractional
                 pos = n.dot(scalemat, [x, y, z, 1])
-                adp = float(text[i][60:66])/(8*n.pi**2) # B to U
+                adp = float(text[i][60:66]) / (8 * n.pi**2)  # B to U
                 adp_type = 'Uiso'
                 occ = float(text[i][54:60])
                 multi = multiplicity(pos, self.atomlist.sgname)
                 self.atomlist.add_atom(label=label,
                                        atomtype=atomtype,
-                                       pos = pos,
-                                       adp_type= adp_type,
-                                       adp = adp,
+                                       pos=pos,
+                                       adp_type=adp_type,
+                                       adp=adp,
                                        occ=occ,
                                        symmulti=multi)
 
                 self.atomlist.dispersion[atomtype] = None
 
-
-    def CIFread(self, ciffile = None, cifblkname = None, cifblk = None, verbose=True):
+    def CIFread(
+            self,
+            ciffile=None,
+            cifblkname=None,
+            cifblk=None,
+            verbose=True):
         from re import sub
-        if ciffile != None:
+        if ciffile is not None:
             try:
                 cifblk = self.CIFopen(ciffile=ciffile, cifblkname=cifblkname)
-            except:
+            except BaseException:
                 raise
-        elif cifblk == None:
+        elif cifblk is None:
             cifblk = self.cifblk
 
         self.atomlist.cell = [self.remove_esd(cifblk['_cell_length_a']),
@@ -340,9 +350,9 @@ class build_atomlist:
                               self.remove_esd(cifblk['_cell_angle_beta']),
                               self.remove_esd(cifblk['_cell_angle_gamma'])]
 
-        #self.atomlist.sgname = upper(sub("\s+","",
+        # self.atomlist.sgname = upper(sub("\s+","",
         #                       cifblk['_symmetry_space_group_name_H-M']))
-        self.atomlist.sgname = sub("\s+", "",
+        self.atomlist.sgname = sub("\\s+", "",
                                    cifblk['_symmetry_space_group_name_H-M'])
 
         # Dispersion factors
@@ -351,17 +361,24 @@ class build_atomlist:
                 try:
                     self.atomlist.dispersion[cifblk['_atom_type_symbol'][i].upper()] =\
                         [self.remove_esd(cifblk['_atom_type_scat_dispersion_real'][i]),
-                        self.remove_esd(cifblk['_atom_type_scat_dispersion_imag'][i])]
-                except:
-                    self.atomlist.dispersion[cifblk['_atom_type_symbol'][i].upper()] = None
-                    if verbose: logging.warning('No dispersion factors for %s in cif file - set to zero'\
-                                        %cifblk['_atom_type_symbol'][i])
+                         self.remove_esd(cifblk['_atom_type_scat_dispersion_imag'][i])]
+                except BaseException:
+                    self.atomlist.dispersion[cifblk['_atom_type_symbol'][i].upper(
+                    )] = None
+                    if verbose:
+                        logging.warning(
+                            'No dispersion factors for %s in cif file - set to zero' %
+                            cifblk['_atom_type_symbol'][i])
         else:
-            if verbose: logging.warning('No _atom_type_symbol found in CIF')
+            if verbose:
+                logging.warning('No _atom_type_symbol found in CIF')
             for i in range(len(cifblk['_atom_site_type_symbol'])):
-                self.atomlist.dispersion[cifblk['_atom_site_type_symbol'][i].upper()] = None
-                if verbose: logging.warning('No dispersion factors for %s in cif file - set to zero'\
-                                        %cifblk['_atom_site_type_symbol'][i])
+                self.atomlist.dispersion[cifblk['_atom_site_type_symbol'][i].upper(
+                )] = None
+                if verbose:
+                    logging.warning(
+                        'No dispersion factors for %s in cif file - set to zero' %
+                        cifblk['_atom_site_type_symbol'][i])
 
         for i in range(len(cifblk['_atom_site_type_symbol'])):
             label = cifblk['_atom_site_label'][i]
@@ -372,51 +389,54 @@ class build_atomlist:
             z = self.remove_esd(cifblk['_atom_site_fract_z'][i])
             try:
                 adp_type = cifblk['_atom_site_adp_type'][i]
-            except:
+            except BaseException:
                 adp_type = None
             try:
                 occ = self.remove_esd(cifblk['_atom_site_occupancy'][i])
-            except:
+            except BaseException:
                 occ = 1.0
 
             if '_atom_site_symmetry_multiplicity' in cifblk:
-                multi = self.remove_esd(cifblk['_atom_site_symmetry_multiplicity'][i])
+                multi = self.remove_esd(
+                    cifblk['_atom_site_symmetry_multiplicity'][i])
             # In old SHELXL versions this code was written
             # as '_atom_site_symetry_multiplicity'
             elif '_atom_site_symetry_multiplicity' in cifblk:
-                multi = self.remove_esd(cifblk['_atom_site_symetry_multiplicity'][i])
+                multi = self.remove_esd(
+                    cifblk['_atom_site_symetry_multiplicity'][i])
             else:
                 multi = multiplicity([x, y, z], self.atomlist.sgname)
 
             # Test for B or U
 
-            if adp_type == None:
+            if adp_type is None:
                 adp = 0.0
             elif adp_type == 'Biso':
-                adp = self.remove_esd(cifblk['_atom_site_B_iso_or_equiv'][i])/(8*n.pi**2)
+                adp = self.remove_esd(
+                    cifblk['_atom_site_B_iso_or_equiv'][i]) / (8 * n.pi**2)
                 adp_type = 'Uiso'
             elif adp_type == 'Bani':
                 anisonumber = cifblk['_atom_site_aniso_label'].index(label)
-                adp = [ self.remove_esd(cifblk['_atom_site_aniso_B_11'][anisonumber])/(8*n.pi**2),
-                        self.remove_esd(cifblk['_atom_site_aniso_B_22'][anisonumber])/(8*n.pi**2),
-                        self.remove_esd(cifblk['_atom_site_aniso_B_33'][anisonumber])/(8*n.pi**2),
-                        self.remove_esd(cifblk['_atom_site_aniso_B_23'][anisonumber])/(8*n.pi**2),
-                        self.remove_esd(cifblk['_atom_site_aniso_B_13'][anisonumber])/(8*n.pi**2),
-                        self.remove_esd(cifblk['_atom_site_aniso_B_12'][anisonumber])/(8*n.pi**2)]
+                adp = [self.remove_esd(cifblk['_atom_site_aniso_B_11'][anisonumber]) / (8 * n.pi**2),
+                       self.remove_esd(cifblk['_atom_site_aniso_B_22'][anisonumber]) / (8 * n.pi**2),
+                       self.remove_esd(cifblk['_atom_site_aniso_B_33'][anisonumber]) / (8 * n.pi**2),
+                       self.remove_esd(cifblk['_atom_site_aniso_B_23'][anisonumber]) / (8 * n.pi**2),
+                       self.remove_esd(cifblk['_atom_site_aniso_B_13'][anisonumber]) / (8 * n.pi**2),
+                       self.remove_esd(cifblk['_atom_site_aniso_B_12'][anisonumber]) / (8 * n.pi**2)]
                 adp_type = 'Uani'
             elif adp_type == 'Uiso':
                 adp = self.remove_esd(cifblk['_atom_site_U_iso_or_equiv'][i])
             elif adp_type == 'Uani':
                 anisonumber = cifblk['_atom_site_aniso_label'].index(label)
-                adp = [ self.remove_esd(cifblk['_atom_site_aniso_U_11'][anisonumber]),
-                        self.remove_esd(cifblk['_atom_site_aniso_U_22'][anisonumber]),
-                        self.remove_esd(cifblk['_atom_site_aniso_U_33'][anisonumber]),
-                        self.remove_esd(cifblk['_atom_site_aniso_U_23'][anisonumber]),
-                        self.remove_esd(cifblk['_atom_site_aniso_U_13'][anisonumber]),
-                        self.remove_esd(cifblk['_atom_site_aniso_U_12'][anisonumber])]
+                adp = [self.remove_esd(cifblk['_atom_site_aniso_U_11'][anisonumber]),
+                       self.remove_esd(cifblk['_atom_site_aniso_U_22'][anisonumber]),
+                       self.remove_esd(cifblk['_atom_site_aniso_U_33'][anisonumber]),
+                       self.remove_esd(cifblk['_atom_site_aniso_U_23'][anisonumber]),
+                       self.remove_esd(cifblk['_atom_site_aniso_U_13'][anisonumber]),
+                       self.remove_esd(cifblk['_atom_site_aniso_U_12'][anisonumber])]
             self.atomlist.add_atom(label=label, atomtype=atomtype,
-                                   pos = [x, y, z], adp_type= adp_type,
-                                   adp = adp, occ=occ , symmulti=multi)
+                                   pos=[x, y, z], adp_type=adp_type,
+                                   adp=adp, occ=occ, symmulti=multi)
 
     def remove_esd(self, a):
         """
@@ -424,11 +444,8 @@ class build_atomlist:
         e.g. '1.234(56)' to '1.234'.
         """
 
-
         if a.find('(') == -1:
             value = float(a)
         else:
             value = float(a[:a.find('(')])
         return value
-
-
